@@ -3,9 +3,9 @@
 package Test::Sah::Schema;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-01'; # DATE
+our $DATE = '2020-03-03'; # DATE
 our $DIST = 'Test-Sah-Schema'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -191,13 +191,39 @@ sub sah_schema_modules_ok {
 
     $Test->plan(tests => 1);
 
-    my @modules = all_modules(@starters);
-    if (@modules) {
+    my @include_modules;
+    {
+        my $val = delete $opts->{include_modules};
+        last unless $val;
+        for my $mod (@$val) {
+            $mod = "Sah::Schema::$mod" unless $mod =~ /^Sah::Schema::/;
+            push @include_modules, $mod;
+        }
+    }
+    my @exclude_modules;
+    {
+        my $val = delete $opts->{exclude_modules};
+        last unless $val;
+        for my $mod (@$val) {
+            $mod = "Sah::Schema::$mod" unless $mod =~ /^Sah::Schema::/;
+            push @exclude_modules, $mod;
+        }
+    }
+
+    my @all_modules = all_modules(@starters);
+    if (@all_modules) {
         $Test->subtest(
             "Sah schema modules in dist",
             sub {
-                for my $module (@modules) {
+                for my $module (@all_modules) {
                     next unless $module =~ /\ASah::Schema::/;
+                    if (@include_modules) {
+                        next unless grep { $module eq $_ } @include_modules;
+                    }
+                    if (@exclude_modules) {
+                        next if grep { $module eq $_ } @exclude_modules;
+                    }
+
                     log_info "Processing module %s ...", $module;
                     my $thismsg = defined $msg ? $msg :
                         "Sah schema module in $module";
@@ -228,7 +254,7 @@ Test::Sah::Schema - Test Sah::Schema::* modules in distribution
 
 =head1 VERSION
 
-This document describes version 0.001 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-01.
+This document describes version 0.002 of Test::Sah::Schema (from Perl distribution Test-Sah-Schema), released on 2020-03-03.
 
 =head1 SYNOPSIS
 
@@ -283,7 +309,15 @@ Whether to test examples in schema.
 Look for modules in directory C<lib> (or C<blib> instead, if it exists), and
 C<run sah_schema_module_ok()> on each of them.
 
-Options are the same as in C<sah_schema_module_ok()>.
+Options are the same as in C<sah_schema_module_ok()>, plus:
+
+=over
+
+=item * include_modules
+
+=item * exclude_modules
+
+=back
 
 =head1 HOMEPAGE
 
